////////////////////////////////////////////////////////////////////////////////
//Taylor Electronics Services (TES)                                            /
//                                                                             /
//  This source code is public domain.                                         /
////////////////////////////////////////////////////////////////////////////////
//revision history                                                             /
//2007/06/20        Initial release                                            /
////////////////////////////////////////////////////////////////////////////////
//I/O to RAM translation: this gets away from the input()/output() statements  /
//in PICC which don't translate well to other compilers, especially when the   /
//background I/O direction control of PICC is taken into consideration.  If the/
//programmer is comfortable with #use fast_io(x) then this is essentially the  /
//same.                                                                        /
//                                                                             /
//1.  Parts are grouped by memory organization.                                /
//2.  Parts with only pin registers do not have latch names to force awareness /
//    of the hardware.                                                         /
//3.  Input (1), Output (0), True (1), False (0), High (1) and Low (0) are     /
//    defined here                                                             /
////////////////////////////////////////////////////////////////////////////////
#define input1      0x1
#define output1     0x0
#define input8      0xff
#define output8     0x00      
#define high        1
#define low         0
#ifndef true
  #define true      1     //defined in version 4 of compiler
#endif
#ifndef false
  #define false     0
#endif
#define nak         0
#define ack         1
////////////////////////////////////////////////////////////////////////////////
#nolist
////////////////////////////////////////////////////////////////////////////////
//Example
//Set entire port B to inputs, read port B
//Set RA2 as input, read RA2, set RA2 as output and then write 0 to RA2
/*
#include    "pinmap.h"

void main(void){
int8 rdport;
int1 rdpin;

while(true){
bdir=0xff;
rdport=bpin;

a2dir=input;
rdpin=a2pin;
a2dir=output;
a2lat=0;
}}
*/
////////////////////////////////////////////////////////////////////////////////
//devices translated
//..............................................................................
//PIC10F
//..............................................................................
//PIC12F
//..............................................................................
//PIC16F     87
//           88
//          631
//          677
//          685
//          687
//          689
//          690
//          873
//          874
//          876
//          877
//..............................................................................
//PIC18F    242
//          252
//          442
//          452
//         2420
//         2520
//         4420
//         4520
//         6520
//         6527
//         6550 = 65J50
//         6620
//         6627
//         6622
//         6720
//         6722
//         8520
//         8527
//         8620
//         8622
//         8627
//         8720
//         8722
////////////////////////////////////////////////////////////////////////////////
//16F87
#if (__device__==87)||(__device__==88)
  #define xxproctypexx 87
#endif
//------------------------------------------------------------------------------
//16F631
#if (__device__==631)||(__device__==677)||(__device__==685)||(__device__==687)
  #define xxproctypexx 631
#endif
#if (__device__==689)||(__device__==690)
  #define xxproctypexx 631
#endif
//------------------------------------------------------------------------------
//PIC16F 28 pin
#if (__device__==873)||(__device__==876)
  #define xxproctypexx 873
#endif
//------------------------------------------------------------------------------
//PIC16F 40/44 pin
#if (__device__==874)||(__device__==877)
  #define xxproctypexx 874
#endif
//------------------------------------------------------------------------------
//PIC18F 28 pin
#if (__device__==242)||(__device__==252)
  #define xxproctypexx 242
#endif
//------------------------------------------------------------------------------
//PIC18F 40/44 pin
#if (__device__==442)||(__device__==452)
  #define xxproctypexx 442
#endif
//------------------------------------------------------------------------------
//PIC18F 28 pin
#if (__device__==2420)|(__device__==2520)
  #define xxproctypexx 2420
#endif
//------------------------------------------------------------------------------
//PIC18F 40/44 pin
#if (__device__==4420)|(__device__==4520)
  #define xxproctypexx 4420
#endif
//------------------------------------------------------------------------------
//PIC18F 64 pin
#if (__device__==6520)||(__device__==6620)||(__device__==6720)
  #define xxproctypexx 6520
#endif
//------------------------------------------------------------------------------
//PIC18F 64 pin
#if (__device__==6550)
  #define xxproctypexx 6550
#endif
//------------------------------------------------------------------------------
//PIC18F 64 pin, mclr is (i) and oscin is (i/o)
#if (__device__==6527)||(__device__==6622)||(__device__==6627)||(__device__==6722)
  #define xxproctypexx 6527
#endif
//------------------------------------------------------------------------------
//PIC18F 80 pin
#if (__device__==8520)||(__device__==8620)||(__device__==8720)
  #define xxproctypexx 8520
#endif
//------------------------------------------------------------------------------
//PIC18F 80 pin, mclr is (i) and oscin is (i/o)
#if (__device__==8527)||(__device__==8622)||(__device__==8627)||(__device__==8722)
  #define xxproctypexx 8527
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 87)
#list
//PIC16F87 style pinmap
//..............................................................................
//pins
#byte   apin        =0x05
#byte   bpin        =0x06
//tris
#byte   adir        =0x85
#byte   bdir        =0x86
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 631)
#list
//PIC16F631 style pinmap
//..............................................................................
//pins
#byte   apin        =0x05
#byte   bpin        =0x06
#byte   cpin        =0x07
//tris
#byte   adir        =0x85
#byte   bdir        =0x86
#byte   cdir        =0x87
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
//port b
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
//port b
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 242)
#list
//PIC18F242 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 442)
#list
//PIC18F442 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 2420)
#list
//PIC18F2420 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   epin        =0xf84      //only e3 input pin
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
//#byte elat        =0xf8d      //only e3 but no lat register
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
//#byte edir        =0xf96      //only e3 but no dir register
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
#bit    a7pin       =apin.7
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port e
#bit    e3pin       =epin.3
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
#bit    a7lat       =alat.7
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port e
//#bit  e3lat       =elat.3     //input only and only if no mclr
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
#bit    a7dir       =adir.7
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port e
//#bit  e3dir       =edir.3     //input only and only if no mclr
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 4420)
#list
//PIC18F4420 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
#bit    a7pin       =apin.7
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
#bit    e3pin       =epin.3
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
#bit    a7lat       =alat.7
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
//#bit  e3lat       =elat.3   //input only and only if no mclr
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
#bit    a7dir       =adir.7
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
//#bit  e3dir       =edir.3   //input only and only if no mclr
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 873)
#list
//PIC16F873 style pinmap
//..............................................................................
//pins
#byte   apin        =0x05
#byte   bpin        =0x06
#byte   cpin        =0x07
//tris
#byte   adir        =0x85
#byte   bdir        =0x86
#byte   cdir        =0x87
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 874)
#list
//PIC16F874 style pinmap
//..............................................................................
//pins
#byte   apin        =0x05
#byte   bpin        =0x06
#byte   cpin        =0x07
#byte   dpin        =0x08
#byte   epin        =0x09
//tris
#byte   adir        =0x85
#byte   bdir        =0x86
#byte   cdir        =0x87
#byte   ddir        =0x88
#byte   edir        =0x89
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 6520)
#list
//PIC18F6520 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
#byte   fpin        =0xf85
#byte   gpin        =0xf86
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
#byte   flat        =0xf8e
#byte   glat        =0xf8f
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
#byte   fdir        =0xf97
#byte   gdir        =0xf98
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
#bit    e3pin       =epin.3
#bit    e4pin       =epin.4
#bit    e5pin       =epin.5
#bit    e6pin       =epin.6
#bit    e7pin       =epin.7
//port f
#bit    f0pin       =fpin.0
#bit    f1pin       =fpin.1
#bit    f2pin       =fpin.2
#bit    f3pin       =fpin.3
#bit    f4pin       =fpin.4
#bit    f5pin       =fpin.5
#bit    f6pin       =fpin.6
#bit    f7pin       =fpin.7
//port g
#bit    g0pin       =gpin.0
#bit    g1pin       =gpin.1
#bit    g2pin       =gpin.2
#bit    g3pin       =gpin.3
#bit    g4pin       =gpin.4
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
#bit    e3lat       =elat.3
#bit    e4lat       =elat.4
#bit    e5lat       =elat.5
#bit    e6lat       =elat.6
#bit    e7lat       =elat.7
//port f
#bit    f0lat       =flat.0
#bit    f1lat       =flat.1
#bit    f2lat       =flat.2
#bit    f3lat       =flat.3
#bit    f4lat       =flat.4
#bit    f5lat       =flat.5
#bit    f6lat       =flat.6
#bit    f7lat       =flat.7
//port g
#bit    g0lat       =glat.0
#bit    g1lat       =glat.1
#bit    g2lat       =glat.2
#bit    g3lat       =glat.3
#bit    g4lat       =glat.4
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
#bit    e3dir       =edir.3
#bit    e4dir       =edir.4
#bit    e5dir       =edir.5
#bit    e6dir       =edir.6
#bit    e7dir       =edir.7
//port f
#bit    f0dir       =fdir.0
#bit    f1dir       =fdir.1
#bit    f2dir       =fdir.2
#bit    f3dir       =fdir.3
#bit    f4dir       =fdir.4
#bit    f5dir       =fdir.5
#bit    f6dir       =fdir.6
#bit    f7dir       =fdir.7
//port g
#bit    g0dir       =gdir.0
#bit    g1dir       =gdir.1
#bit    g2dir       =gdir.2
#bit    g3dir       =gdir.3
#bit    g4dir       =gdir.4
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 6527)
#list
//PIC18F6527 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
#byte   fpin        =0xf85
#byte   gpin        =0xf86

//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
#byte   flat        =0xf8e
#byte   glat        =0xf8f
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
#byte   fdir        =0xf97
#byte   gdir        =0xf98
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
#bit    a7pin       =apin.7
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
#bit    e3pin       =epin.3
#bit    e4pin       =epin.4
#bit    e5pin       =epin.5
#bit    e6pin       =epin.6
#bit    e7pin       =epin.7
//port f
#bit    f0pin       =fpin.0
#bit    f1pin       =fpin.1
#bit    f2pin       =fpin.2
#bit    f3pin       =fpin.3
#bit    f4pin       =fpin.4
#bit    f5pin       =fpin.5
#bit    f6pin       =fpin.6
#bit    f7pin       =fpin.7
//port g
#bit    g0pin       =gpin.0
#bit    g1pin       =gpin.1
#bit    g2pin       =gpin.2
#bit    g3pin       =gpin.3
#bit    g4pin       =gpin.4
#bit    g5pin       =gpin.5     //input only and only if no mclr
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
#bit    a7lat       =alat.7
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
#bit    e3lat       =elat.3
#bit    e4lat       =elat.4
#bit    e5lat       =elat.5
#bit    e6lat       =elat.6
#bit    e7lat       =elat.7
//port f
#bit    f0lat       =flat.0
#bit    f1lat       =flat.1
#bit    f2lat       =flat.2
#bit    f3lat       =flat.3
#bit    f4lat       =flat.4
#bit    f5lat       =flat.5
#bit    f6lat       =flat.6
#bit    f7lat       =flat.7
//port g
#bit    g0lat       =glat.0
#bit    g1lat       =glat.1
#bit    g2lat       =glat.2
#bit    g3lat       =glat.3
#bit    g4lat       =glat.4
//#bit  g5lat       =glat.5     //input only and only if no mclr
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
#bit    a7dir       =adir.7
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
#bit    e3dir       =edir.3
#bit    e4dir       =edir.4
#bit    e5dir       =edir.5
#bit    e6dir       =edir.6
#bit    e7dir       =edir.7
//port f
#bit    f0dir       =fdir.0
#bit    f1dir       =fdir.1
#bit    f2dir       =fdir.2
#bit    f3dir       =fdir.3
#bit    f4dir       =fdir.4
#bit    f5dir       =fdir.5
#bit    f6dir       =fdir.6
#bit    f7dir       =fdir.7
//port g
#bit    g0dir       =gdir.0
#bit    g1dir       =gdir.1
#bit    g2dir       =gdir.2
#bit    g3dir       =gdir.3
#bit    g4dir       =gdir.4
//#bit  g5dir       =gdir.5     //input only and only if no mclr
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 6550)
#list
//PIC18F6550 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
#byte   fpin        =0xf85
#byte   gpin        =0xf86

//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
#byte   flat        =0xf8e
#byte   glat        =0xf8f
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
#byte   fdir        =0xf97
#byte   gdir        =0xf98
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
#bit    a7pin       =apin.7
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
#bit    e3pin       =epin.3
#bit    e4pin       =epin.4
#bit    e5pin       =epin.5
#bit    e6pin       =epin.6
#bit    e7pin       =epin.7
//port f
//#bit    f0pin       =fpin.0  //ENVREG
//#bit    f1pin       =fpin.1  //VUSB
#bit    f2pin       =fpin.2
#bit    f3pin       =fpin.3
#bit    f4pin       =fpin.4
#bit    f5pin       =fpin.5
#bit    f6pin       =fpin.6
#bit    f7pin       =fpin.7
//port g
#bit    g0pin       =gpin.0
#bit    g1pin       =gpin.1
#bit    g2pin       =gpin.2
#bit    g3pin       =gpin.3
#bit    g4pin       =gpin.4
#bit    g5pin       =gpin.5     //input only and only if no mclr
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
#bit    a7lat       =alat.7
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
#bit    e3lat       =elat.3
#bit    e4lat       =elat.4
#bit    e5lat       =elat.5
#bit    e6lat       =elat.6
#bit    e7lat       =elat.7
//port f
//#bit    f0lat       =flat.0  //envreg
//#bit    f1lat       =flat.1  //vusb
#bit    f2lat       =flat.2
#bit    f3lat       =flat.3
#bit    f4lat       =flat.4
#bit    f5lat       =flat.5
#bit    f6lat       =flat.6
#bit    f7lat       =flat.7
//port g
#bit    g0lat       =glat.0
#bit    g1lat       =glat.1
#bit    g2lat       =glat.2
#bit    g3lat       =glat.3
#bit    g4lat       =glat.4
//#bit  g5lat       =glat.5     //input only and only if no mclr
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
#bit    a7dir       =adir.7
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
#bit    e3dir       =edir.3
#bit    e4dir       =edir.4
#bit    e5dir       =edir.5
#bit    e6dir       =edir.6
#bit    e7dir       =edir.7
//port f
//#bit    f0dir       =fdir.0  //envreg
//#bit    f1dir       =fdir.1  //vusb
#bit    f2dir       =fdir.2
#bit    f3dir       =fdir.3
#bit    f4dir       =fdir.4
#bit    f5dir       =fdir.5
#bit    f6dir       =fdir.6
#bit    f7dir       =fdir.7
//port g
#bit    g0dir       =gdir.0
#bit    g1dir       =gdir.1
#bit    g2dir       =gdir.2
#bit    g3dir       =gdir.3
#bit    g4dir       =gdir.4
//#bit  g5dir       =gdir.5     //input only and only if no mclr
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 8520)
#list
//PIC18F8520 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
#byte   fpin        =0xf85
#byte   gpin        =0xf86
#byte   hpin        =0xf87
#byte   jpin        =0xf88
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
#byte   flat        =0xf8e
#byte   glat        =0xf8f
#byte   hlat        =0xf90
#byte   jlat        =0xf91
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
#byte   fdir        =0xf97
#byte   gdir        =0xf98
#byte   hdir        =0xf99
#byte   jdir        =0xf9a
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
#bit    e3pin       =epin.3
#bit    e4pin       =epin.4
#bit    e5pin       =epin.5
#bit    e6pin       =epin.6
#bit    e7pin       =epin.7
//port f
#bit    f0pin       =fpin.0
#bit    f1pin       =fpin.1
#bit    f2pin       =fpin.2
#bit    f3pin       =fpin.3
#bit    f4pin       =fpin.4
#bit    f5pin       =fpin.5
#bit    f6pin       =fpin.6
#bit    f7pin       =fpin.7
//port g
#bit    g0pin       =gpin.0
#bit    g1pin       =gpin.1
#bit    g2pin       =gpin.2
#bit    g3pin       =gpin.3
#bit    g4pin       =gpin.4
//port h
#bit    h0pin       =hpin.0
#bit    h1pin       =hpin.1
#bit    h2pin       =hpin.2
#bit    h3pin       =hpin.3
#bit    h4pin       =hpin.4
#bit    h5pin       =hpin.5
#bit    h6pin       =hpin.6
#bit    h7pin       =hpin.7
//port j
#bit    j0pin       =jpin.0
#bit    j1pin       =jpin.1
#bit    j2pin       =jpin.2
#bit    j3pin       =jpin.3
#bit    j4pin       =jpin.4
#bit    j5pin       =jpin.5
#bit    j6pin       =jpin.6
#bit    j7pin       =jpin.7
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
#bit    e3lat       =elat.3
#bit    e4lat       =elat.4
#bit    e5lat       =elat.5
#bit    e6lat       =elat.6
#bit    e7lat       =elat.7
//port f
#bit    f0lat       =flat.0
#bit    f1lat       =flat.1
#bit    f2lat       =flat.2
#bit    f3lat       =flat.3
#bit    f4lat       =flat.4
#bit    f5lat       =flat.5
#bit    f6lat       =flat.6
#bit    f7lat       =flat.7
//port g
#bit    g0lat       =glat.0
#bit    g1lat       =glat.1
#bit    g2lat       =glat.2
#bit    g3lat       =glat.3
#bit    g4lat       =glat.4
//port h
#bit    h0lat       =hlat.0
#bit    h1lat       =hlat.1
#bit    h2lat       =hlat.2
#bit    h3lat       =hlat.3
#bit    h4lat       =hlat.4
#bit    h5lat       =hlat.5
#bit    h6lat       =hlat.6
#bit    h7lat       =hlat.7
//port j
#bit    j0lat       =jlat.0
#bit    j1lat       =jlat.1
#bit    j2lat       =jlat.2
#bit    j3lat       =jlat.3
#bit    j4lat       =jlat.4
#bit    j5lat       =jlat.5
#bit    j6lat       =jlat.6
#bit    j7lat       =jlat.7
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
#bit    e3dir       =edir.3
#bit    e4dir       =edir.4
#bit    e5dir       =edir.5
#bit    e6dir       =edir.6
#bit    e7dir       =edir.7
//port f
#bit    f0dir       =fdir.0
#bit    f1dir       =fdir.1
#bit    f2dir       =fdir.2
#bit    f3dir       =fdir.3
#bit    f4dir       =fdir.4
#bit    f5dir       =fdir.5
#bit    f6dir       =fdir.6
#bit    f7dir       =fdir.7
//port g
#bit    g0dir       =gdir.0
#bit    g1dir       =gdir.1
#bit    g2dir       =gdir.2
#bit    g3dir       =gdir.3
#bit    g4dir       =gdir.4
//port h
#bit    h0dir       =hdir.0
#bit    h1dir       =hdir.1
#bit    h2dir       =hdir.2
#bit    h3dir       =hdir.3
#bit    h4dir       =hdir.4
#bit    h5dir       =hdir.5
#bit    h6dir       =hdir.6
#bit    h7dir       =hdir.7
//port j
#bit    j0dir       =jdir.0
#bit    j1dir       =jdir.1
#bit    j2dir       =jdir.2
#bit    j3dir       =jdir.3
#bit    j4dir       =jdir.4
#bit    j5dir       =jdir.5
#bit    j6dir       =jdir.6
#bit    j7dir       =jdir.7
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#if (xxproctypexx == 8527)
#list
//PIC18F8527 style pinmap
//..............................................................................
//pins
#byte   apin        =0xf80
#byte   bpin        =0xf81
#byte   cpin        =0xf82
#byte   dpin        =0xf83
#byte   epin        =0xf84
#byte   fpin        =0xf85
#byte   gpin        =0xf86
#byte   hpin        =0xf87
#byte   jpin        =0xf88
//latches
#byte   alat        =0xf89
#byte   blat        =0xf8a
#byte   clat        =0xf8b
#byte   dlat        =0xf8c
#byte   elat        =0xf8d
#byte   flat        =0xf8e
#byte   glat        =0xf8f
#byte   hlat        =0xf90
#byte   jlat        =0xf91
//tris
#byte   adir        =0xf92
#byte   bdir        =0xf93
#byte   cdir        =0xf94
#byte   ddir        =0xf95
#byte   edir        =0xf96
#byte   fdir        =0xf97
#byte   gdir        =0xf98
#byte   hdir        =0xf99
#byte   jdir        =0xf9a
//..............................................................................
//pin registers
//port a
#bit    a0pin       =apin.0
#bit    a1pin       =apin.1
#bit    a2pin       =apin.2
#bit    a3pin       =apin.3
#bit    a4pin       =apin.4
#bit    a5pin       =apin.5
#bit    a6pin       =apin.6
#bit    a7pin       =apin.7
//port b
#bit    b0pin       =bpin.0
#bit    b1pin       =bpin.1
#bit    b2pin       =bpin.2
#bit    b3pin       =bpin.3
#bit    b4pin       =bpin.4
#bit    b5pin       =bpin.5
#bit    b6pin       =bpin.6
#bit    b7pin       =bpin.7
//port c
#bit    c0pin       =cpin.0
#bit    c1pin       =cpin.1
#bit    c2pin       =cpin.2
#bit    c3pin       =cpin.3
#bit    c4pin       =cpin.4
#bit    c5pin       =cpin.5
#bit    c6pin       =cpin.6
#bit    c7pin       =cpin.7
//port d
#bit    d0pin       =dpin.0
#bit    d1pin       =dpin.1
#bit    d2pin       =dpin.2
#bit    d3pin       =dpin.3
#bit    d4pin       =dpin.4
#bit    d5pin       =dpin.5
#bit    d6pin       =dpin.6
#bit    d7pin       =dpin.7
//port e
#bit    e0pin       =epin.0
#bit    e1pin       =epin.1
#bit    e2pin       =epin.2
#bit    e3pin       =epin.3
#bit    e4pin       =epin.4
#bit    e5pin       =epin.5
#bit    e6pin       =epin.6
#bit    e7pin       =epin.7
//port f
#bit    f0pin       =fpin.0
#bit    f1pin       =fpin.1
#bit    f2pin       =fpin.2
#bit    f3pin       =fpin.3
#bit    f4pin       =fpin.4
#bit    f5pin       =fpin.5
#bit    f6pin       =fpin.6
#bit    f7pin       =fpin.7
//port g
#bit    g0pin       =gpin.0
#bit    g1pin       =gpin.1
#bit    g2pin       =gpin.2
#bit    g3pin       =gpin.3
#bit    g4pin       =gpin.4
#bit    g5pin       =gpin.5
//port h
#bit    h0pin       =hpin.0
#bit    h1pin       =hpin.1
#bit    h2pin       =hpin.2
#bit    h3pin       =hpin.3
#bit    h4pin       =hpin.4
#bit    h5pin       =hpin.5
#bit    h6pin       =hpin.6
#bit    h7pin       =hpin.7
//port j
#bit    j0pin       =jpin.0
#bit    j1pin       =jpin.1
#bit    j2pin       =jpin.2
#bit    j3pin       =jpin.3
#bit    j4pin       =jpin.4
#bit    j5pin       =jpin.5
#bit    j6pin       =jpin.6
#bit    j7pin       =jpin.7
//..............................................................................
//latch
//port a
#bit    a0lat       =alat.0
#bit    a1lat       =alat.1
#bit    a2lat       =alat.2
#bit    a3lat       =alat.3
#bit    a4lat       =alat.4
#bit    a5lat       =alat.5
#bit    a6lat       =alat.6
#bit    a7lat       =alat.7
//port b
#bit    b0lat       =blat.0
#bit    b1lat       =blat.1
#bit    b2lat       =blat.2
#bit    b3lat       =blat.3
#bit    b4lat       =blat.4
#bit    b5lat       =blat.5
#bit    b6lat       =blat.6
#bit    b7lat       =blat.7
//port c
#bit    c0lat       =clat.0
#bit    c1lat       =clat.1
#bit    c2lat       =clat.2
#bit    c3lat       =clat.3
#bit    c4lat       =clat.4
#bit    c5lat       =clat.5
#bit    c6lat       =clat.6
#bit    c7lat       =clat.7
//port d
#bit    d0lat       =dlat.0
#bit    d1lat       =dlat.1
#bit    d2lat       =dlat.2
#bit    d3lat       =dlat.3
#bit    d4lat       =dlat.4
#bit    d5lat       =dlat.5
#bit    d6lat       =dlat.6
#bit    d7lat       =dlat.7
//port e
#bit    e0lat       =elat.0
#bit    e1lat       =elat.1
#bit    e2lat       =elat.2
#bit    e3lat       =elat.3
#bit    e4lat       =elat.4
#bit    e5lat       =elat.5
#bit    e6lat       =elat.6
#bit    e7lat       =elat.7
//port f
#bit    f0lat       =flat.0
#bit    f1lat       =flat.1
#bit    f2lat       =flat.2
#bit    f3lat       =flat.3
#bit    f4lat       =flat.4
#bit    f5lat       =flat.5
#bit    f6lat       =flat.6
#bit    f7lat       =flat.7
//port g
#bit    g0lat       =glat.0
#bit    g1lat       =glat.1
#bit    g2lat       =glat.2
#bit    g3lat       =glat.3
#bit    g4lat       =glat.4
//#bit  g5lat       =glat.5     //input only and only if no mclr
//port h
#bit    h0lat       =hlat.0
#bit    h1lat       =hlat.1
#bit    h2lat       =hlat.2
#bit    h3lat       =hlat.3
#bit    h4lat       =hlat.4
#bit    h5lat       =hlat.5
#bit    h6lat       =hlat.6
#bit    h7lat       =hlat.7
//port j
#bit    j0lat       =jlat.0
#bit    j1lat       =jlat.1
#bit    j2lat       =jlat.2
#bit    j3lat       =jlat.3
#bit    j4lat       =jlat.4
#bit    j5lat       =jlat.5
#bit    j6lat       =jlat.6
#bit    j7lat       =jlat.7
//..............................................................................
//tris
//port a
#bit    a0dir       =adir.0
#bit    a1dir       =adir.1
#bit    a2dir       =adir.2
#bit    a3dir       =adir.3
#bit    a4dir       =adir.4
#bit    a5dir       =adir.5
#bit    a6dir       =adir.6
#bit    a7dir       =adir.7
//port b
#bit    b0dir       =bdir.0
#bit    b1dir       =bdir.1
#bit    b2dir       =bdir.2
#bit    b3dir       =bdir.3
#bit    b4dir       =bdir.4
#bit    b5dir       =bdir.5
#bit    b6dir       =bdir.6
#bit    b7dir       =bdir.7
//port c
#bit    c0dir       =cdir.0
#bit    c1dir       =cdir.1
#bit    c2dir       =cdir.2
#bit    c3dir       =cdir.3
#bit    c4dir       =cdir.4
#bit    c5dir       =cdir.5
#bit    c6dir       =cdir.6
#bit    c7dir       =cdir.7
//port d
#bit    d0dir       =ddir.0
#bit    d1dir       =ddir.1
#bit    d2dir       =ddir.2
#bit    d3dir       =ddir.3
#bit    d4dir       =ddir.4
#bit    d5dir       =ddir.5
#bit    d6dir       =ddir.6
#bit    d7dir       =ddir.7
//port e
#bit    e0dir       =edir.0
#bit    e1dir       =edir.1
#bit    e2dir       =edir.2
#bit    e3dir       =edir.3
#bit    e4dir       =edir.4
#bit    e5dir       =edir.5
#bit    e6dir       =edir.6
#bit    e7dir       =edir.7
//port f
#bit    f0dir       =fdir.0
#bit    f1dir       =fdir.1
#bit    f2dir       =fdir.2
#bit    f3dir       =fdir.3
#bit    f4dir       =fdir.4
#bit    f5dir       =fdir.5
#bit    f6dir       =fdir.6
#bit    f7dir       =fdir.7
//port g
#bit    g0dir       =gdir.0
#bit    g1dir       =gdir.1
#bit    g2dir       =gdir.2
#bit    g3dir       =gdir.3
#bit    g4dir       =gdir.4
//#bit  g5dir       =gdir.5     //input only and only if no mclr
//port h
#bit    h0dir       =hdir.0
#bit    h1dir       =hdir.1
#bit    h2dir       =hdir.2
#bit    h3dir       =hdir.3
#bit    h4dir       =hdir.4
#bit    h5dir       =hdir.5
#bit    h6dir       =hdir.6
#bit    h7dir       =hdir.7
//port j
#bit    j0dir       =jdir.0
#bit    j1dir       =jdir.1
#bit    j2dir       =jdir.2
#bit    j3dir       =jdir.3
#bit    j4dir       =jdir.4
#bit    j5dir       =jdir.5
#bit    j6dir       =jdir.6
#bit    j7dir       =jdir.7
//..............................................................................
#nolist
#endif
////////////////////////////////////////////////////////////////////////////////
#list
////////////////////////////////////////////////////////////////////////////////



